==> gcc-4.1_4.1.2.orig.tar.gz: gcc-4.1.2/libjava/classpath/java/nio/channels/spi/AbstractSelectionKey.java <==
/* AbstractSelectionKey.java --
   Copyright (C) 2002, 2003, 2004  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package java.nio.channels.spi;

import java.nio.channels.SelectionKey;


/**
 * @since 1.4
 */
public abstract class AbstractSelectionKey extends SelectionKey
{
  private boolean cancelled;

  /**
   * Initializes the key.
   */
  protected AbstractSelectionKey()
  {
  }

  /**
   * Cancels this key.
   */
  public final void cancel()
  {
    if (isValid())
      {
	((AbstractSelector) selector()).cancelKey(this);
	cancelled = true;
      }
  }

  /**
   * Tells whether this key is valid or not.
   *
   * @return true if this key is valid, false otherwise
   */
  public final boolean isValid()
  {
    return ! cancelled;
  }
}

==> gcc-4.7_4.7.4.orig.tar.gz: gcc-4.7.4/libjava/classpath/java/nio/channels/spi/AbstractSelectionKey.java <==
/* AbstractSelectionKey.java --
   Copyright (C) 2002, 2003, 2004, 2006  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package java.nio.channels.spi;

import java.nio.channels.SelectionKey;


/**
 * @since 1.4
 */
public abstract class AbstractSelectionKey extends SelectionKey
{
  private boolean cancelled;

  /**
   * Initializes the key.
   */
  protected AbstractSelectionKey()
  {
  }

  /**
   * Cancels this key.
   */
  public final synchronized void cancel()
  {
    if (isValid())
      {
        ((AbstractSelector) selector()).cancelKey(this);
        cancelled = true;
      }
  }

  /**
   * Tells whether this key is valid or not.
   *
   * @return true if this key is valid, false otherwise
   */
  public final synchronized boolean isValid()
  {
    return ! cancelled;
  }
}
